@@ -10,7 +10,7 @@ from piptools.repositories import PyPIRepository
 from piptools.repositories.pypi import open_local_or_remote_file
 
 
-def test_generate_hashes_all_platforms(pip_conf, from_line, pypi_repository):
+def test_generate_hashes_all_platforms(capfd, pip_conf, from_line, pypi_repository):
     expected = {
         "sha256:8d4d131cd05338e09f461ad784297efea3652e542c5fabe04a62358429a6175e",
         "sha256:ad05e1371eb99f257ca00f791b755deb22e752393eb8e75bc01d651715b02ea9",
@@ -20,6 +20,12 @@ def test_generate_hashes_all_platforms(pip_conf, from_line, pypi_repository):
     ireq = from_line("small-fake-multi-arch==0.1")
     with pypi_repository.allow_all_wheels():
         assert pypi_repository.get_hashes(ireq) == expected
+    captured = capfd.readouterr()
+    assert captured.out == ""
+    assert (
+        captured.err.strip()
+        == "Couldn't get hashes from PyPI, fallback to hashing files"
+    )
 
 
 @pytest.mark.network
@@ -60,6 +66,14 @@ def test_get_hashes_editable_empty_set(from_editable, pypi_repository):
     assert pypi_repository.get_hashes(ireq) == set()
 
 
+def test_get_hashes_unpinned_raises(from_line, pypi_repository):
+    # Under normal pip-tools usage, get_hashes() should never be called with an
+    # unpinned requirement. The TypeError represents a programming mistake.
+    ireq = from_line("django")
+    with pytest.raises(TypeError, match=r"^Expected pinned requirement, got django"):
+        pypi_repository.get_hashes(ireq)
+
+
 @pytest.mark.parametrize(("content", "content_length"), ((b"foo", 3), (b"foobar", 6)))
 def test_open_local_or_remote_file__local_file(tmp_path, content, content_length):
     """
@@ -109,23 +123,30 @@ def test_open_local_or_remote_file__remote_file(
     response_file_path.write_bytes(content)
 
     mock_response = mock.Mock()
-    mock_response.raw = response_file_path.open("rb")
-    mock_response.headers = {"content-length": content_length}
+    with response_file_path.open("rb") as fp:
+        mock_response.raw = fp
+        mock_response.headers = {"content-length": content_length}
 
-    with mock.patch.object(session, "get", return_value=mock_response):
-        with open_local_or_remote_file(link, session) as file_stream:
-            assert file_stream.stream.read() == content
-            assert file_stream.size == expected_content_length
+        with mock.patch.object(session, "get", return_value=mock_response):
+            with open_local_or_remote_file(link, session) as file_stream:
+                assert file_stream.stream.read() == content
+                assert file_stream.size == expected_content_length
 
-    mock_response.close.assert_called_once()
+        mock_response.close.assert_called_once()
 
 
 def test_pypirepo_build_dir_is_str(pypi_repository):
-    assert isinstance(pypi_repository.build_dir, str)
+    assert pypi_repository.build_dir is None
+    with pypi_repository.freshen_build_caches():
+        assert isinstance(pypi_repository.build_dir, str)
+    assert pypi_repository.build_dir is None
 
 
 def test_pypirepo_source_dir_is_str(pypi_repository):
-    assert isinstance(pypi_repository.source_dir, str)
+    assert pypi_repository.source_dir is None
+    with pypi_repository.freshen_build_caches():
+        assert isinstance(pypi_repository.source_dir, str)
+    assert pypi_repository.source_dir is None
 
 
 def test_relative_path_cache_dir_is_normalized(from_line):
