@@ -1,11 +1,12 @@
 # coding: utf-8
 from __future__ import unicode_literals
 
+import logging
 import os
 
 import pytest
-import six
-from six.moves import shlex_quote
+from pip._vendor import six
+from pip._vendor.six.moves import shlex_quote
 
 from piptools.scripts.compile import cli as compile_cli
 from piptools.utils import (
@@ -178,15 +179,24 @@ def test_is_pinned_requirement_editable(from_editable):
         ("https://example.com/example.zip", True),
         ("https://example.com/example.zip#egg=example", True),
         ("git+git://github.com/jazzband/pip-tools@master", True),
-        ("../example.zip", True),
-        ("/example.zip", True),
     ),
 )
-def test_is_url_requirement(from_line, line, expected):
+def test_is_url_requirement(caplog, from_line, line, expected):
     ireq = from_line(line)
     assert is_url_requirement(ireq) is expected
 
 
+@pytest.mark.parametrize("line", ("../example.zip", "/example.zip"))
+def test_is_url_requirement_filename(caplog, from_line, line):
+    # Ignore warning:
+    #
+    #     Requirement '../example.zip' looks like a filename, but the file does
+    #     not exist
+    caplog.set_level(logging.ERROR, logger="pip")
+    ireq = from_line(line)
+    assert is_url_requirement(ireq) is True
+
+
 def test_name_from_req(from_line):
     ireq = from_line("django==1.8")
     assert name_from_req(ireq.req) == "django"
@@ -205,7 +215,7 @@ def test_fs_str():
 
 @pytest.mark.skipif(six.PY2, reason="Not supported in py2")
 def test_fs_str_with_bytes():
-    with pytest.raises(AssertionError):
+    with pytest.raises(TypeError, match=r"^fs_str\(\) argument must not be bytes$"):
         fs_str(b"whatever")
 
 
@@ -250,6 +260,7 @@ def test_force_text(value, expected_text):
         (["--no-emit-index-url"], "pip-compile --no-emit-index-url"),
         (["--no-emit-trusted-host"], "pip-compile --no-emit-trusted-host"),
         (["--no-annotate"], "pip-compile --no-annotate"),
+        (["--no-allow-unsafe"], "pip-compile"),
         # Check that default values will be removed from the command
         (["--emit-trusted-host"], "pip-compile"),
         (["--annotate"], "pip-compile"),
